@@ -13,10 +13,13 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.ClientEvent;
 import org.gnu.gnome.event.ClientListener;
-import org.gnu.gtk.GtkObject;
+import org.gnu.gtk.Dialog;
+import org.gnu.glib.Handle;
+
 /**
  * The GnomeClient object makes it possible for your application to
  * save session information when the user logs out. If, when logging
@@ -25,7 +28,7 @@ import org.gnu.gtk.GtkObject;
  * information in such a way that it is supported on the command line
  * whenever the program automatically restarts a user login.
  */
-public class Client extends GtkObject {
+public class Client extends GObject {
 	/**
 	 * Listeners for handling Client events
 	 */
@@ -42,9 +45,23 @@ public class Client extends GtkObject {
 	/**
 	 * Initialize a client from a handle to a native resource.
 	 */
-	protected Client(int handle) {
+	protected Client(Handle handle) {
 		super(handle);
 	}
+    
+    protected static Client getClient(Handle handle) {
+        if (handle == null) {
+            return null;
+        }
+        
+        Client obj = (Client) GObject.getGObjectFromHandle(handle);
+        
+        if (obj == null) {
+            obj = new Client(handle);
+        }
+        
+        return obj;
+    }
 
 	/**
 	 * Get the config prefix for a client.  The config prefix provides
@@ -53,7 +70,7 @@ public class Client extends GtkObject {
 	 * arguments (as set in the restart command).
 	 */
 	public String getConfigPrefix() {
-		return new String(gnome_client_get_config_prefix(getHandle()));
+		return gnome_client_get_config_prefix(getHandle());
 	}
 	
 	/**
@@ -67,7 +84,7 @@ public class Client extends GtkObject {
 	 * a different way so it should be used with caution.
 	 */
 	public String getGlobalConfigPrefix() {
-		return new String(gnome_client_get_global_config_prefix(getHandle()));
+		return gnome_client_get_global_config_prefix(getHandle());
 	}
 	
 	/**
@@ -131,7 +148,52 @@ public class Client extends GtkObject {
 	public void setRestartCommand(String [] args) {
 		gnome_client_set_restart_command(getHandle(), args.length, args);
 	}
-	
+    
+    public void setDiscardCommand(String[] args) {
+        gnome_client_set_discard_command(getHandle(), args.length, args);
+    }
+    
+    public void setResignCommand(String[] args) {
+        gnome_client_set_resign_command(getHandle(), args.length, args);
+    }
+    
+    public void setShutdownCommand(String[] args) {
+        gnome_client_set_shutdown_command(getHandle(), args.length, args);
+    }
+
+    public void setEnvironment(String name, String value) {
+        gnome_client_set_environment(getHandle(), name, value);
+    }
+    
+    public void setCloneCommand(String[] args) {
+        gnome_client_set_clone_command(getHandle(), args.length, args);
+    }
+    
+    public void setProcessID(int id) {
+        gnome_client_set_process_id(getHandle(), id);
+    }
+    
+    public void setProgram(String program) {
+        gnome_client_set_program(getHandle(), program);
+    }
+    
+    public void setUserID(String id) {
+        gnome_client_set_user_id(getHandle(), id);
+    }
+    
+    public void saveAnyDialog(Dialog dialog) {
+        gnome_client_save_any_dialog(getHandle(), dialog.getHandle());
+    }
+    
+    public void saveErrorDialog(Dialog dialog) {
+        gnome_client_save_error_dialog(getHandle(), dialog.getHandle());
+    }
+    
+    public void requestPhase2() {
+        gnome_client_request_phase_2(getHandle());
+    }
+    
+
 	/**
 	 * Request the session manager to save the session in some way.
 	 */
@@ -163,7 +225,23 @@ public class Client extends GtkObject {
 		gnome_client_disconnect(getHandle());
 	}
 
-	/**
+    public void setID(String id) {
+        gnome_client_set_id(getHandle(), id);
+    }
+    
+    public String getID() {
+        return gnome_client_get_id(getHandle());
+    }
+    
+    public String getPreviousID() {
+        return gnome_client_get_previous_id(getHandle());
+    }
+    
+    public String getDesktopID() {
+        return gnome_client_get_desktop_id(getHandle());
+    }
+
+    /**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
 	public static Type getType() {
@@ -293,39 +371,35 @@ public class Client extends GtkObject {
 		anEvtMap.addEvent("shutdown_cancelled", "handleShutdownCancelled", ClientEvent.Type.SHUTDOWN_CANCELLED, ClientListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_client_get_type();
-	native static final protected String gnome_client_get_config_prefix(int client);
-	native static final protected String gnome_client_get_global_config_prefix(int client);
-	native static final protected void gnome_client_set_global_config_prefix(int client, String prefix);
-	native static final protected int gnome_client_get_flags(int client);
-	native static final protected void gnome_client_set_restart_style(int client, int style);
-	native static final protected void gnome_client_set_priority(int client, int priority);
-	native static final protected void gnome_client_set_restart_command(int client, int argc, String[] args);
-	native static final protected void gnome_client_set_discard_command(int client, int argc, String[] args);
-	native static final protected void gnome_client_set_resign_command(int client, int argc, String[] args);
-	native static final protected void gnome_client_set_shutdown_command(int client, int argc, String[] args);
-	native static final protected void gnome_client_set_current_directory(int client, String dir);
-	native static final protected void gnome_client_set_environment(int client, String name, String value);
-	native static final protected void gnome_client_set_clone_command(int client, int argc, String[] args);
-	native static final protected void gnome_client_set_process_id(int client, int id);
-	native static final protected void gnome_client_set_program(int client, String program);
-	native static final protected void gnome_client_set_user_id(int client, String id);
-	native static final protected void gnome_client_save_any_dialog(int client, int dialog);
-	native static final protected void gnome_client_save_error_dialog(int client, int dialog);
-	native static final protected void gnome_client_request_phase_2(int client);
-	native static final protected void gnome_client_request_save(int client, int save_style, boolean shutdown, int interact_style, boolean fast, boolean global);
-	native static final protected void gnome_client_flush(int client);
-	native static final protected int gnome_client_new();
-	native static final protected void gnome_client_connect(int client);
-	native static final protected void gnome_client_disconnect(int client);
-	native static final protected void gnome_client_set_id(int client, String id);
-	native static final protected String gnome_client_get_id(int client);
-	native static final protected String gnome_client_get_previous_id(int client);
-	native static final protected String gnome_client_get_desktop_id(int client);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected String gnome_client_get_config_prefix(Handle client);
+	native static final protected String gnome_client_get_global_config_prefix(Handle client);
+	native static final protected void gnome_client_set_global_config_prefix(Handle client, String prefix);
+	native static final protected int gnome_client_get_flags(Handle client);
+	native static final protected void gnome_client_set_restart_style(Handle client, int style);
+	native static final protected void gnome_client_set_priority(Handle client, int priority);
+	native static final protected void gnome_client_set_restart_command(Handle client, int argc, String[] args);
+	native static final protected void gnome_client_set_discard_command(Handle client, int argc, String[] args);
+	native static final protected void gnome_client_set_resign_command(Handle client, int argc, String[] args);
+	native static final protected void gnome_client_set_shutdown_command(Handle client, int argc, String[] args);
+	native static final protected void gnome_client_set_current_directory(Handle client, String dir);
+	native static final protected void gnome_client_set_environment(Handle client, String name, String value);
+	native static final protected void gnome_client_set_clone_command(Handle client, int argc, String[] args);
+	native static final protected void gnome_client_set_process_id(Handle client, int id);
+	native static final protected void gnome_client_set_program(Handle client, String program);
+	native static final protected void gnome_client_set_user_id(Handle client, String id);
+	native static final protected void gnome_client_save_any_dialog(Handle client, Handle dialog);
+	native static final protected void gnome_client_save_error_dialog(Handle client, Handle dialog);
+	native static final protected void gnome_client_request_phase_2(Handle client);
+	native static final protected void gnome_client_request_save(Handle client, int save_style, boolean shutdown, int interact_style, boolean fast, boolean global);
+	native static final protected void gnome_client_flush(Handle client);
+	native static final protected Handle gnome_client_new();
+	native static final protected void gnome_client_connect(Handle client);
+	native static final protected void gnome_client_disconnect(Handle client);
+	native static final protected void gnome_client_set_id(Handle client, String id);
+	native static final protected String gnome_client_get_id(Handle client);
+	native static final protected String gnome_client_get_previous_id(Handle client);
+	native static final protected String gnome_client_get_desktop_id(Handle client);
+
 }
