@@ -8,12 +8,13 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Boxed;
+
+import org.gnu.glib.Struct;
 
 /**
  * @deprecated
  */
-public class Config extends Boxed 
+public class Config extends Struct 
 {
 	
 	static public String getString(String path) {
