@@ -8,13 +8,14 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.GObject;
+
 import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Container;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.Window;
+
 /**
  * The GNOME druid is a system for assisting the user with installing a
  * service. It is roughly equivalent in functionality to the Wizards
@@ -110,10 +111,7 @@ public class Druid extends Container {
 	 */
 	public Button getHelpButton() {
 		Handle hndl = getHelp(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Button)obj;
-		return new Button(hndl);
+        return Button.getButton(hndl);
 	}
 	
 	/**
@@ -121,10 +119,7 @@ public class Druid extends Container {
 	 */
 	public Button getBackButton() {
 		Handle hndl = getBack(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Button)obj;
-		return new Button(hndl);
+		return Button.getButton(hndl);
 	}
 	
 	/**
@@ -132,10 +127,7 @@ public class Druid extends Container {
 	 */
 	public Button getNextButton() {
 		Handle hndl = getNext(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Button)obj;
-		return new Button(hndl);
+		return Button.getButton(hndl);
 	}
 	
 	/**
@@ -143,10 +135,7 @@ public class Druid extends Container {
 	 */
 	public Button getCancelButton() {
 		Handle hndl = getCancel(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Button)obj;
-		return new Button(hndl);
+        return Button.getButton(hndl);
 	}
 	
 	/**
@@ -154,10 +143,7 @@ public class Druid extends Container {
 	 */
 	public Button getFinishButton() {
 		Handle hndl = getFinish(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Button)obj;
-		return new Button(hndl);
+        return Button.getButton(hndl);
 	}
 	
 	/**
