@@ -12,7 +12,7 @@ package org.gnu.gnome;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.VBox;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * This widget provides an entry box with history and a button which can pop up a
@@ -20,6 +20,7 @@ import org.gnu.javagnome.Handle;
  * other sources.
  * 
  * @deprecated
+ * @see org.gnu.gtk.FileChooser
  */
 public class FileEntry extends VBox {
 	/**
