@@ -9,8 +9,8 @@
 
 package org.gnu.gnome;
 
-import org.gnu.javagnome.Handle;
-import org.gnu.javagnome.Struct;
+import org.gnu.glib.Handle;
+import org.gnu.glib.Struct;
 
 public class GConf extends Struct
 {
