@@ -9,7 +9,8 @@
 
 package org.gnu.gnome;
 
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
+import org.gnu.gtk.Config;
 
 public class Gnome 
 {
@@ -22,7 +23,7 @@ public class Gnome
 	 * is finished. 
 	 */
 	public static Client getMasterClient() {
-		return new Client(gnome_master_client());
+		return Client.getClient(gnome_master_client());
 	}
 	
 	/**
@@ -34,10 +35,10 @@ public class Gnome
 	}
 	
 
-    static
-    {
-		System.loadLibrary ("gtkjni-2.7");
-        System.loadLibrary ("gnomejni-2.11");
+    static {
+        System.loadLibrary(Config.LIBRARY_NAME + Config.GTK_API_VERSION);
+        System.loadLibrary(GnomeConfig.LIBRARY_NAME
+                + GnomeConfig.GNOME_API_VERSION);
     }
 
     native static final protected Handle gnome_master_client ();
