@@ -13,7 +13,7 @@ import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Editable;
 import org.gnu.gtk.Entry;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * @deprecated
