@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 #include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -23,7 +24,7 @@ extern "C"
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasPathDef_gnome_1canvas_1path_1def_1new (JNIEnv 
     *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gnome_canvas_path_def_new ());
+    return getGObjectHandle(env, G_OBJECT(gnome_canvas_path_def_new ()));
 }
 
 /*
@@ -34,7 +35,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasPathDef_gnome_1canvas_1path_1
     JNIEnv *env, jclass cls, jint length) 
 {
     gint32 length_g = (gint32) length;
-    return getHandleFromPointer(env, gnome_canvas_path_def_new_sized (length_g));
+    return getGObjectHandle(env, G_OBJECT(gnome_canvas_path_def_new_sized (length_g)));
 }
 
 /*
@@ -91,7 +92,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasPathDef_gnome_1canvas_1path_1
     JNIEnv *env, jclass cls, jobject path) 
 {
     GnomeCanvasPathDef *path_g = (GnomeCanvasPathDef *)getPointerFromHandle(env, path);
-    return getHandleFromPointer(env, gnome_canvas_path_def_duplicate (path_g));
+    return getGObjectHandle(env, G_OBJECT(gnome_canvas_path_def_duplicate (path_g)));
 }
 
 /*
