@@ -8,8 +8,10 @@
  */
 
 #include <jni.h>
+#include <pango/pango.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 #include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -293,7 +295,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getStipple (JNIEnv *env,
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_stipple (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_stipple (cptr_g)));
 }
 
 void GnomeCanvasText_set_stipple (GnomeCanvasText * cptr, GdkBitmap * stipple) 
@@ -325,7 +327,7 @@ GdkGC * GnomeCanvasText_get_gc (GnomeCanvasText * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getGc (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_gc (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_gc (cptr_g)));
 }
 
 gint32 GnomeCanvasText_get_max_width (GnomeCanvasText * cptr) 
@@ -406,7 +408,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getFontDesc (JNIEnv *env
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_font_desc (cptr_g));
+    return getGBoxedHandle(env, GnomeCanvasText_get_font_desc (cptr_g),
+    		PANGO_TYPE_FONT_DESCRIPTION,
+    		(GBoxedCopyFunc) pango_font_description_copy,
+    		(GBoxedFreeFunc) pango_font_description_free);
 }
 
 void GnomeCanvasText_set_font_desc (GnomeCanvasText * cptr, PangoFontDescription * font_desc) 
@@ -439,7 +444,9 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getAttrList (JNIEnv *env
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_attr_list (cptr_g));
+    return getGBoxedHandle(env, GnomeCanvasText_get_attr_list (cptr_g),
+    		PANGO_TYPE_ATTR_LIST, (GBoxedCopyFunc) pango_attr_list_copy,
+    		(GBoxedFreeFunc) pango_attr_list_unref);
 }
 
 void GnomeCanvasText_set_attr_list (GnomeCanvasText * cptr, PangoAttrList * attr_list) 
@@ -603,7 +610,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getLayout (JNIEnv *env,
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_layout (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_layout (cptr_g)));
 }
 
 void GnomeCanvasText_set_layout (GnomeCanvasText * cptr, PangoLayout * layout) 
