@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -36,8 +37,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DateEdit_gnome_1date_1edit_1new (JN
     time_t the_time_g = (time_t) the_time;
     gboolean show_time_g = (gboolean) show_time;
     gboolean use_24_format_g = (gboolean) use_24_format;
-    return getHandleFromPointer(env,
-    		gnome_date_edit_new (the_time_g, show_time_g, use_24_format_g));
+    return getGObjectHandle(env,
+    		G_OBJECT(gnome_date_edit_new (the_time_g, show_time_g, use_24_format_g)));
 }
 
 /*
@@ -49,8 +50,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DateEdit_gnome_1date_1edit_1new_1fl
 {
     time_t the_time_g = (time_t) the_time;
     GnomeDateEditFlags flags_g = (GnomeDateEditFlags) flags;
-    return getHandleFromPointer(env,
-    		gnome_date_edit_new_flags (the_time_g, flags_g));
+    return getGObjectHandle(env,
+    		G_OBJECT(gnome_date_edit_new_flags (the_time_g, flags_g)));
 }
 
 /*
