@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -33,7 +34,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_DruidPage_gnome_1druid_1page_1get_1typ
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPage_gnome_1druid_1page_1new (JNIEnv *env, 
     jclass cls) 
 {
-    return getHandleFromPointer(env, gnome_druid_page_new ());
+    return getGObjectHandle(env, G_OBJECT(gnome_druid_page_new ()));
 }
 
 /*
