@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -22,7 +23,7 @@ extern "C"
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_Gnome_gnome_1master_1client (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gnome_master_client ());
+    return getGObjectHandleAndRef(env, G_OBJECT(gnome_master_client ()));
 }
 
 /*
