@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -34,7 +35,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_HRef_gnome_1href_1new (JNIEnv *env,
 {
     const gchar* url_g = (*env)->GetStringUTFChars(env, url, NULL);
     const gchar* lable_g = (*env)->GetStringUTFChars(env, lable, NULL);
-	jobject retval =  getHandleFromPointer(env, gnome_href_new (url_g, lable_g));
+	jobject retval =  getGObjectHandle(env, G_OBJECT(gnome_href_new (url_g, lable_g)));
 	(*env)->ReleaseStringUTFChars( env, url, url_g);
 	(*env)->ReleaseStringUTFChars( env, lable, lable_g );
 	return retval;
